@@ -1,8 +1,8 @@
 !== Command line arguments parser
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_args.f90,v 1.4 2006/05/31 12:18:27 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dc_args.f90,v 1.5 2006/10/09 11:00:06 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -23,7 +23,7 @@ module dc_args
   ! Open     :: ¤ ARGS ѿν
   ! Close    :: ¤ ARGS ѿνλ
   ! Get      :: ޥɥ饤μ
-  ! Size     :: ޥɥ饤ο֤
+  ! Number   :: ޥɥ饤ο֤
   ! Option   :: ޥɥ饤ץ뤿
   ! Debug    :: ǥХåץμư
   ! Help     :: إץץμư
@@ -75,7 +75,7 @@ module dc_args
   !       call Debug(arg); call Help(arg) ; call Strict(arg)
   !
   !       if (OPT_size) then
-  !         write(*,*) 'number of arguments :: ', size(arg)
+  !         write(*,*) 'number of arguments :: ', Number(arg)
   !       end if
   !       if (OPT_namelist) then
   !         write(*,*) '--namelist=', trim(VAL_namelist)
@@ -98,7 +98,7 @@ module dc_args
 
   public:: ARGS
   public:: Open, Close, Option, Put_Line, Debug, Help, HelpMsg, Strict, Get
-  public:: Size
+  public:: Number
 
   type ARGS
     !
@@ -174,8 +174,8 @@ module dc_args
     module procedure DCArgsGet
   end interface
 
-  interface Size
-    module procedure DCArgsSize
+  interface Number
+    module procedure DCArgsNumber
   end interface
 
 
@@ -509,7 +509,7 @@ contains
     !       integer :: i
     !
     !       call Open(arg)
-    !       call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.4 $ :: Test program of dc_args')
+    !       call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.5 $ :: Test program of dc_args')
     !       call HelpMsg(arg, 'Usage', 'dcargs [Options] arg1, arg2, ...')
     !       call Option(arg, StoA('-N', '--namelist'), & 
     !         & OPT_namelist, VAL_namelist, help="Namelist filename")
@@ -629,7 +629,7 @@ contains
     end do
   end subroutine DCArgsGet
 
-  function DCArgsSize(arg) result(result)
+  function DCArgsNumber(arg) result(result)
     !
     !=== ޥɥ饤ο֤
     !
@@ -646,7 +646,7 @@ contains
       call DCArgsOpen(arg)
     end if
     result = size(cmd_argv_list)
-  end function DCArgsSize
+  end function DCArgsNumber
 
   subroutine DCArgsPut_Line(arg)
     !
