@@ -1,8 +1,8 @@
 !== dc_date.f90 - ա˴ؤ³󶡤⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_date.f90,v 1.4 2006/01/15 13:23:37 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dc_date.f90,v 1.5 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -68,12 +68,12 @@ module dc_date
       character(len = *), intent(in):: string
     end subroutine DCDateLetFC
 
-    subroutine DCDateLetFS(diff, string)
-      use dc_date_types, only: DC_DIFFTIME
-      use dc_string, only: VSTRING
-      type(DC_DIFFTIME), intent(out):: diff
-      type(VSTRING), intent(in):: string
-    end subroutine DCDateLetFS
+!!$    subroutine DCDateLetFS(diff, string)
+!!$      use dc_date_types, only: DC_DIFFTIME
+!!$      use dc_string, only: VSTRING
+!!$      type(DC_DIFFTIME), intent(out):: diff
+!!$      type(VSTRING), intent(in):: string
+!!$    end subroutine DCDateLetFS
 
     subroutine DCDateLetTC(time, string)
       use dc_date_types, only: DC_DATETIME
@@ -81,30 +81,30 @@ module dc_date
       character(len = *), intent(in):: string
     end subroutine DCDateLetTC
 
-    subroutine DCDateLetTS(time, string)
-      use dc_date_types, only: DC_DATETIME
-      use dc_string, only: VSTRING
-      type(DC_DATETIME), intent(out):: time
-      type(VSTRING), intent(in):: string
-    end subroutine DCDateLetTS
+!!$    subroutine DCDateLetTS(time, string)
+!!$      use dc_date_types, only: DC_DATETIME
+!!$      use dc_string, only: VSTRING
+!!$      type(DC_DATETIME), intent(out):: time
+!!$      type(VSTRING), intent(in):: string
+!!$    end subroutine DCDateLetTS
 
   end interface
 
-  interface toString
-
-    type(VSTRING) function DCDateDiffToString(diff)
-      use dc_date_types, only: DC_DIFFTIME
-      use dc_string, only: VSTRING
-      type(DC_DIFFTIME), intent(in):: diff
-    end function DCDateDiffToString
-
-    type(VSTRING) function DCDateTimeToString(time)
-      use dc_date_types, only: DC_DATETIME
-      use dc_string, only: VSTRING
-      type(DC_DATETIME), intent(in):: time
-    end function DCDateTimeToString
-
-  end interface
+!!$  interface toString
+!!$
+!!$    type(VSTRING) function DCDateDiffToString(diff)
+!!$      use dc_date_types, only: DC_DIFFTIME
+!!$      use dc_string, only: VSTRING
+!!$      type(DC_DIFFTIME), intent(in):: diff
+!!$    end function DCDateDiffToString
+!!$
+!!$    type(VSTRING) function DCDateTimeToString(time)
+!!$      use dc_date_types, only: DC_DATETIME
+!!$      use dc_string, only: VSTRING
+!!$      type(DC_DATETIME), intent(in):: time
+!!$    end function DCDateTimeToString
+!!$
+!!$  end interface
 
   interface Eval
 
