@@ -1,8 +1,8 @@
 !== dc_error.f90 - 顼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.8 2006/06/04 12:48:43 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dc_error.f90,v 1.9 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -486,7 +486,6 @@ contains
     ! ץλ롣
     !++
 
-    use dc_string, only: assignment(=)
     integer,            intent(in)            :: number  ! 顼
     character(len = *), intent(in)            :: where   ! 顼ȯĽ
     logical,            intent(out), optional :: err
@@ -523,7 +522,6 @@ subroutine DumpError()
   !  sysdep#AbortProgram Ϥƥץλޤ
   !
   use dc_types, only: STRING
-  use dc_string, only: put_line
   use dc_error, only: GetErrorMessage
   use sysdep, only: AbortProgram
   character(len = STRING):: message
