@@ -1,8 +1,8 @@
 !== Hash module
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_hash.f90,v 1.3 2006/05/31 14:17:48 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dc_hash.f90,v 1.4 2006/10/09 11:00:06 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -25,7 +25,7 @@ module dc_hash
   ! Rewind   :: ϥåΤõ뤿ν
   ! Next     :: Rewind 
   ! Delete   :: Ϳ, ϥåδϢͤ
-  ! Size     :: ϥåΥ֤
+  ! Number   :: ϥåΥ֤
   ! Put_Line :: ϥåƤɸϤ˽ (ǥХå)
   !
   !
@@ -44,7 +44,7 @@ module dc_hash
   !      call Get(hashv, 'key1', value)
   !      write(*,*) 'key=' // 'key1' // ', value=' // trim(value)
   !
-  !      write(*,*) 'size(hashv)=', Size(hashv)
+  !      write(*,*) 'number(hashv)=', Number(hashv)
   !
   !      call Delete(hashv, 'key1')
   !
@@ -60,7 +60,7 @@ module dc_hash
   ! ʲΤ褦˽Ϥޤ.
   !
   !      key=key1, value=val1
-  !      size(hashv)= 3
+  !      number(hashv)= 3
   !      key=key2, value=val2
   !      key=key3, value=val3
   !
@@ -70,7 +70,7 @@ module dc_hash
   private
 
   public:: HASH
-  public:: Put, Put_Line, Get, Rewind, Next, Delete, Size
+  public:: Put, Put_Line, Get, Rewind, Next, Delete, Number
 
   type HASH
     !
@@ -93,8 +93,8 @@ module dc_hash
     module procedure DCHashPut
   end interface
 
-  interface Size
-    module procedure DCHashSize
+  interface Number
+    module procedure DCHashNumber
   end interface
 
   interface Put_Line
@@ -136,7 +136,7 @@ contains
   continue
     call DCHashGet(hashv, key, search_value, found)
     if (.not. found) then
-      table_size = DCHashSize(hashv)
+      table_size = DCHashNumber(hashv)
       if (table_size > 0) then
         allocate(hash_table_tmp(table_size))
         hash_table_tmp = hashv % hash_table
@@ -163,7 +163,7 @@ contains
   end subroutine DCHashPut
 
 
-  function DCHashSize(hashv) result(result)
+  function DCHashNumber(hashv) result(result)
     !
     !=== ϥåΥ
     !
@@ -178,7 +178,7 @@ contains
     else
       result = 0
     end if
-  end function DCHashSize
+  end function DCHashNumber
 
   subroutine DCHashRewind(hashv)
     !
@@ -224,7 +224,7 @@ contains
     integer :: table_size
     character(STRING) :: value_tmp
   continue
-    table_size = DCHashSize(hashv)
+    table_size = DCHashNumber(hashv)
     if (table_size < hashv % search_index) then
       key = ''
       value_tmp = ''
@@ -329,7 +329,7 @@ contains
   continue
     if (present(key)) then
       call DCHashGet(hashv, key, search_value, found)
-      table_size = DCHashSize(hashv)
+      table_size = DCHashNumber(hashv)
       if (found .and. table_size > 1) then
         allocate(hash_table_tmp(table_size))
         hash_table_tmp = hashv % hash_table
