@@ -1,8 +1,8 @@
 !== dc_trace.f90 - ǥХåѥ⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_trace.f90,v 1.6 2006/06/11 08:26:21 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dc_trace.f90,v 1.7 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -345,7 +345,7 @@ contains
     lfirst = .false.
   end subroutine initialize
 
-  subroutine BeginSub(name, fmt, i, r, d, L, s, n, c1, c2, c3, ca, &
+  subroutine BeginSub(name, fmt, i, r, d, L, n, c1, c2, c3, ca, &
     & version)
     !
     !== ץ೫ϤΥå
@@ -379,7 +379,6 @@ contains
     !
     !++
     use dc_types, only: STRING, DP
-    use dcstring_base, only: VSTRING !:nodoc:
     use dc_string, only: cprintf, StrInclude
     character(*), intent(in)          :: name
     character(*), intent(in), optional:: fmt
@@ -387,7 +386,6 @@ contains
     real,         intent(in), optional:: r(:)
     real(DP),     intent(in), optional:: d(:)
     logical,      intent(in), optional:: L(:)
-    type(VSTRING),intent(in), optional:: s(:)
     character(*), intent(in), optional:: c1, c2, c3
     character(*), intent(in), optional:: ca(:)
     character(*), intent(in), optional:: version
@@ -432,7 +430,7 @@ contains
       !== Print Debug message
       !
       if (present(fmt)) then
-        cbuf = cprintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+        cbuf = cprintf(fmt, i, r, d, L, n, c1, c2, c3, ca)
         write(dbg, "(A, A, 'call ', A, ' : ', A)") trim(head), &
           & repeat(indent, level), trim(name_ver), trim(cbuf)
       else
@@ -446,7 +444,7 @@ contains
     table(level) = name
   end subroutine BeginSub
 
-  subroutine EndSub(name, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+  subroutine EndSub(name, fmt, i, r, d, L, n, c1, c2, c3, ca)
     !
     !== ץཪλΥå
     !
@@ -473,7 +471,6 @@ contains
     !
     !++
     use dc_types, only: STRING, DP
-    use dcstring_base, only: VSTRING !:nodoc:
     use dc_string, only: cprintf
     character(*), intent(in)          :: name
     character(*), intent(in), optional:: fmt
@@ -481,7 +478,6 @@ contains
     real,         intent(in), optional:: r(:)
     real(DP),     intent(in), optional:: d(:)
     logical,      intent(in), optional:: L(:)
-    type(VSTRING),intent(in), optional:: s(:)
     character(*), intent(in), optional:: c1, c2, c3
     character(*), intent(in), optional:: ca(:)
     character(STRING):: cbuf
@@ -499,7 +495,7 @@ contains
     endif
     if (debug()) then
       if (present(fmt)) then
-        cbuf = cprintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+        cbuf = cprintf(fmt, i, r, d, L, n, c1, c2, c3, ca)
         write(dbg, "(A, A, 'end ', A, ' : ', A)") trim(head), &
           & repeat(indent, level), trim(name), trim(cbuf)
       else
@@ -509,7 +505,7 @@ contains
     endif
   end subroutine EndSub
 
-  subroutine DbgMessage(fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+  subroutine DbgMessage(fmt, i, r, d, L, n, c1, c2, c3, ca)
     !
     !== ǥХåѥå
     !
@@ -527,14 +523,12 @@ contains
     !
     !++
     use dc_types, only: STRING, DP
-    use dcstring_base, only: VSTRING !:nodoc:
     use dc_string, only: cprintf, toChar
     character(*), intent(in)          :: fmt
     integer,      intent(in), optional:: i(:), n(:)
     real,         intent(in), optional:: r(:)
     real(DP),     intent(in), optional:: d(:)
     logical,      intent(in), optional:: L(:)
-    type(VSTRING),intent(in), optional:: s(:)
     character(*), intent(in), optional:: c1, c2, c3
     character(*), intent(in), optional:: ca(:)
     character(STRING):: cbuf
@@ -542,7 +536,7 @@ contains
     integer          :: meshead_len
   continue
     if (.not. debug()) return
-    cbuf = cprintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+    cbuf = cprintf(fmt, i, r, d, L, n, c1, c2, c3, ca)
     if (level < 1) then
       meshead_tmp = ''
       meshead_len = 0
