@@ -1,8 +1,8 @@
 !== Formatted output conversion
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dcstringcprintf.f90,v 1.5 2006/01/09 22:47:05 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dcstringcprintf.f90,v 1.6 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -12,7 +12,7 @@
 !  C  sprintf(3) Ȥʬ㤦ΤǤդ
 !
 
-function DCStringCPrintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca) result(result)
+function DCStringCPrintf(fmt, i, r, d, L, n, c1, c2, c3, ca) result(result)
   !
   ! եޥåʸ fmt ˽äѴ줿ʸ֤ޤ
   ! 1 fmt ˤϻؼҤޤʸͿޤ
@@ -20,7 +20,6 @@ function DCStringCPrintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca) result(result)
   ! <tt>%</tt> Ѥ <tt>%%</tt>פȵҤޤ
   ! ؼҤ˴ؤƤξܺ٤˴ؤƤ dcstringsprintf.f90 򻲾Ȥ
   !
-  use dcstring_base, only: VSTRING
   use dc_types, only: STRING, DP
   use dc_string, only: Printf
   implicit none
@@ -30,10 +29,9 @@ function DCStringCPrintf(fmt, i, r, d, L, s, n, c1, c2, c3, ca) result(result)
   real, intent(in), optional:: r(:)
   real(DP), intent(in), optional:: d(:)
   logical, intent(in), optional:: L(:)
-  type(VSTRING), intent(in), optional:: s(:)
   character(*), intent(in), optional:: c1, c2, c3
   character(*), intent(in), optional:: ca(:)
 continue
-  call printf(result, fmt, i=i, r=r, d=d, L=L, s=s, n=n, &
+  call printf(result, fmt, i=i, r=r, d=d, L=L, n=n, &
     &         c1=c1, c2=c2, c3=c3, ca=ca)
 end function DCStringCPrintf
