@@ -1,8 +1,8 @@
 !== Formatted output conversion
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dcstringfprintf.f90,v 1.4 2005/12/22 03:17:20 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dcstringfprintf.f90,v 1.5 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -12,7 +12,7 @@
 !  C  sprintf(3) Ȥʬ㤦ΤǤդ
 !
 
-subroutine DCStringFPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+subroutine DCStringFPrintf(unit, fmt, i, r, d, L, n, c1, c2, c3, ca)
   !
   ! եޥåʸ fmt ˽äѴ줿ʸ
   ! ֹ unit ֤ޤunit άˤɸϤ֤ޤ
@@ -21,7 +21,6 @@ subroutine DCStringFPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
   ! <tt>%</tt> Ѥ <tt>%%</tt>פȵҤޤ
   ! ؼҤ˴ؤƤξܺ٤ dcstringsprintf.f90 򻲾Ȥ
   !
-  use dcstring_base, only: VSTRING !:nodoc:
   use dc_types, only: STRING, DP
   use dc_string, only: Printf
   implicit none
@@ -31,12 +30,11 @@ subroutine DCStringFPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
   real, intent(in), optional:: r(:)
   real(DP), intent(in), optional:: d(:)
   logical, intent(in), optional:: L(:)
-  type(VSTRING), intent(in), optional:: s(:)
   character(*), intent(in), optional:: c1, c2, c3
   character(*), intent(in), optional:: ca(:)
   character(STRING):: buf
 continue
-  call printf(buf, fmt, i=i, r=r, d=d, L=L, s=s, n=n, &
+  call printf(buf, fmt, i=i, r=r, d=d, L=L, n=n, &
     & c1=c1, c2=c2, c3=c3, ca=ca)
   if (present(unit)) then
     write(unit, '(A)') trim(buf)
