@@ -1,8 +1,8 @@
 !== Formatted output conversion
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dcstringsprintf.f90,v 1.5 2006/07/17 15:46:47 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: dcstringsprintf.f90,v 1.6 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -140,7 +140,7 @@
 !      write(*,*) trim(output)
 
 
-subroutine DCStringSPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
+subroutine DCStringSPrintf(unit, fmt, i, r, d, L, n, c1, c2, c3, ca)
   !
   ! եޥåʸ fmt ˽äѴ줿ʸ unit ֤ޤ
   ! 2 fmt ˤϻؼҤޤʸͿޤ
@@ -148,7 +148,6 @@ subroutine DCStringSPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
   ! <tt>%</tt> Ѥ <tt>%%</tt>פȵҤޤ
   ! ؼҤ˴ؤƤξܺ٤ dcstringsprintf.f90 򻲾Ȥ
   !
-  use dcstring_base, only: VSTRING, assignment(=) !:nodoc:
   use dc_types,      only: DP
   implicit none
   character(*),     intent(out)         :: unit
@@ -157,7 +156,6 @@ subroutine DCStringSPrintf(unit, fmt, i, r, d, L, s, n, c1, c2, c3, ca)
   real,             intent(in), optional:: r(:)
   real(DP),         intent(in), optional:: d(:)
   logical,          intent(in), optional:: L(:)
-  type(VSTRING),    intent(in), optional:: s(:)
   character(*),     intent(in), optional:: c1, c2, c3
   character(*),     intent(in), optional:: ca(:)
 
@@ -275,11 +273,11 @@ continue
           call append(unit, ucur, "no", stat)
           if (stat /= 0) exit MainLoop
         endif
-      case('s', 'S')
-        if (.not. present(S)) cycle MainLoop
-        ns = ns + 1;  if (ns > size(S)) cycle MainLoop
-        call append(unit, ucur, s(ns)%body(1: s(ns)%len), stat)
-        if (stat /= 0) exit MainLoop
+!!$      case('s', 'S')
+!!$        if (.not. present(S)) cycle MainLoop
+!!$        ns = ns + 1;  if (ns > size(S)) cycle MainLoop
+!!$        call append(unit, ucur, s(ns)%body(1: s(ns)%len), stat)
+!!$        if (stat /= 0) exit MainLoop
       case('c', 'C')
         nc = nc + 1
         if (nc == 1) then
