@@ -1,17 +1,13 @@
 !== Memory variable support
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: gt_mem.f90,v 1.3 2006/07/19 00:42:49 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: gt_mem.f90,v 1.4 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2001-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
-! This file provides gt_mem
-!
-! ѿ򥵥ݡȤޤ (ޤΤȤ)
-
 module gt_mem
-
+  ! ѿ򥵥ݡȤޤ (ޤΤȤ)
   use dc_types, only: STRING, TOKEN, DP
 
   implicit none
@@ -62,13 +58,13 @@ module gt_mem
   end interface
 
   interface put_attr
-    module procedure memattradd_v
+!!$    module procedure memattradd_v
     module procedure memattradd
   end interface
 
   interface get_attr
     module procedure MemAttrGet
-!    module procedure MemAttrGetV
+!!$    module procedure MemAttrGetV
   end interface
 
   private:: memtab_add, memtab_lookup
@@ -131,7 +127,6 @@ contains
   end function memtab_add
 
   subroutine memcreated(var, url, length, xtype, long_name, overwrite, err)
-    use dc_error
     type(MEM_VARIABLE), intent(out):: var
     character(*), intent(in):: url
     integer, intent(in):: length
@@ -183,7 +178,7 @@ contains
   end subroutine memclose
 
   subroutine MemAttrGet(var, name, value, err)
-    use dc_error
+    use dc_error, only: StoreError
     use netcdf_f77, only: nf_enotatt, nf_noerr
     type(mem_variable), intent(in):: var
     character(len = *), intent(in):: name
@@ -264,7 +259,7 @@ contains
 !  end subroutine MemAttrGetV
 
   subroutine MemAttrDel(var, name, err)
-    use dc_error
+    use dc_error, only: StoreError
     use netcdf_f77, only: NF_ENOTATT, nf_noerr
     type(MEM_VARIABLE), intent(in):: var
     character(len = *), intent(in):: name
@@ -339,7 +334,6 @@ contains
   end subroutine memAttrRewind
 
   subroutine memAttrNext(var, name, err)
-    use dc_string
     use netcdf_f77, only: nf_noerr
     type(MEM_VARIABLE), intent(in):: var
     character(len = *), intent(out):: name
@@ -403,46 +397,46 @@ contains
     return
   end subroutine memattradd
 
-  subroutine memattradd_v(var, attrname, attrval)
-    use netcdf_f77, only: nf_noerr, nf_enotatt
-    use dc_string
-    type(MEM_VARIABLE), intent(in):: var
-    character(*), intent(in):: attrname
-    type(vstring), intent(in):: attrval
-    type(mem_variable_entry), pointer:: ent
-    type(attr_chain), pointer:: p
-    integer:: stat
-
-    stat = memtab_lookup(var, ent)
-    if (stat == nf_noerr) then
-      if (associated(ent%current)) then
-        if (ent%current%name == attrname) then
-          p => ent%current
-          goto 100
-        endif
-      endif
-      p => ent%attr
-      do
-        if (.not. associated(p)) exit
-        if (p%name == attrname) goto 100
-        p => p%next
-      enddo
-      stat = nf_enotatt
-    endif
-    allocate(p)
-    nullify(p%next)
-    goto 120
-
-100 continue
-    if (associated(p%cbuf)) then
-      deallocate(p%cbuf)
-    endif
-
-120 continue
-    allocate(p%cbuf(len(attrval)))
-    p%cbuf(:) = attrval
-    return
-  end subroutine memattradd_v
+!!$  subroutine memattradd_v(var, attrname, attrval)
+!!$    use netcdf_f77, only: nf_noerr, nf_enotatt
+!!$    use dc_string
+!!$    type(MEM_VARIABLE), intent(in):: var
+!!$    character(*), intent(in):: attrname
+!!$    type(vstring), intent(in):: attrval
+!!$    type(mem_variable_entry), pointer:: ent
+!!$    type(attr_chain), pointer:: p
+!!$    integer:: stat
+!!$
+!!$    stat = memtab_lookup(var, ent)
+!!$    if (stat == nf_noerr) then
+!!$      if (associated(ent%current)) then
+!!$        if (ent%current%name == attrname) then
+!!$          p => ent%current
+!!$          goto 100
+!!$        endif
+!!$      endif
+!!$      p => ent%attr
+!!$      do
+!!$        if (.not. associated(p)) exit
+!!$        if (p%name == attrname) goto 100
+!!$        p => p%next
+!!$      enddo
+!!$      stat = nf_enotatt
+!!$    endif
+!!$    allocate(p)
+!!$    nullify(p%next)
+!!$    goto 120
+!!$
+!!$100 continue
+!!$    if (associated(p%cbuf)) then
+!!$      deallocate(p%cbuf)
+!!$    endif
+!!$
+!!$120 continue
+!!$    allocate(p%cbuf(len(attrval)))
+!!$    p%cbuf(:) = attrval
+!!$    return
+!!$  end subroutine memattradd_v
 
 
 end module gt_mem
