@@ -2,8 +2,8 @@
 != ѿΥԡ
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: gtvarcreatecopy.f90,v 1.5 2006/06/11 08:28:02 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: gtvarcreatecopy.f90,v 1.6 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -55,8 +55,8 @@ subroutine GTVarCreateCopyC(var, url, copyfrom, copyvalue, &
   character(STRING)                   :: vpart, upart, desturl
   character(TOKEN)                    :: xtype
   character(len = *),      parameter:: version = &
-    & '$Name: gt4f90io-20060908 $' // &
-    & '$Id: gtvarcreatecopy.f90,v 1.5 2006/06/11 08:28:02 morikawa Exp $'
+    & '$Name: gt4f90io-20061009 $' // &
+    & '$Id: gtvarcreatecopy.f90,v 1.6 2006/10/09 10:35:42 morikawa Exp $'
 continue
   call BeginSub('gtvarcreatecopy', 'url=%c copyfrom=%d', &
     & c1=trim(url), i=(/copyfrom%mapid/), version=version)
@@ -125,7 +125,6 @@ contains
   !
   subroutine GTVarCopyDim(to, from, target)
     use gtdata_types
-    use dc_string, only: var_str
     use dc_types, only: token, string
     use dc_url, only: UrlSplit, UrlMerge, operator(.onthesamefile.)
     use gtdata_generic, only: Open, Inquire, Create, copy_attr
@@ -187,7 +186,7 @@ contains
   !-----------------------------------------------------------------
   logical function LookupEquivalent(to, from, file) result(result)
     use dc_types, only: string
-    use dc_string, only: var_str, toChar
+    use dc_string, only: toChar
     use gtdata_generic, only: Inquire, GTVarSearch, Open, get_attr
     type(GT_VARIABLE), intent(out):: to
     type(GT_VARIABLE), intent(in):: from
