@@ -1,8 +1,8 @@
 !== Open GT_VARIABLE of dimension by dimord
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: gtvaropenbydimord.f90,v 1.6 2006/06/16 04:55:09 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: gtvaropenbydimord.f90,v 1.7 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -46,7 +46,7 @@ subroutine GTVarOpenByDimOrd(var, source_var, dimord, count_compact, err)
   use gtdata_generic, only: gt_open => open
   use dc_present, only: present_and_true
   use dc_trace, only: beginsub, endsub, DbgMessage
-  use dc_string, only: var_str, CPrintf
+  use dc_string, only: CPrintf
   use dc_error, only: StoreError, GT_ENOMOREDIMS, GT_ENOMOREDIMS, &
     & DC_NOERR, GT_EFAKE
   use dc_types, only: STRING
@@ -64,8 +64,8 @@ subroutine GTVarOpenByDimOrd(var, source_var, dimord, count_compact, err)
   character(STRING) :: endsub_msg
   character(len = *),      parameter:: subname = "GTVarOpen-By-Dimord"
   character(len = *),      parameter:: version = &
-    & '$Name: gt4f90io-20060908 $' // &
-    & '$Id: gtvaropenbydimord.f90,v 1.6 2006/06/16 04:55:09 morikawa Exp $'
+    & '$Name: gt4f90io-20061009 $' // &
+    & '$Id: gtvaropenbydimord.f90,v 1.7 2006/10/09 10:35:42 morikawa Exp $'
 continue
   call beginsub(subname, 'var.mapid=%d dimord=%d ', &
     & i=(/source_var%mapid, dimord/), version=version)
