@@ -2,8 +2,8 @@
 != ѿΰ
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: gtvarputline.f90,v 1.3 2006/01/15 07:10:30 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20060908 $
+! Version::   $Id: gtvarputline.f90,v 1.4 2006/10/09 10:35:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20061009 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -26,7 +26,7 @@ subroutine GTVarPutLine(var, err)
   !
   use gtdata_types, only: GT_VARIABLE
   use dc_error, only: ErrorCode, StoreError, GT_ENOMEM
-  use dc_string, only: toChar, put_line
+  use dc_string, only: toChar, Printf
   use gtdata_generic, only: Get, Inquire
   use dc_trace, only: beginsub, endsub, DbgMessage
   implicit none
@@ -51,7 +51,7 @@ continue
     goto 950
   endif
   do, i = 1, size(rvalue)
-    call put_line(trim(toChar(rvalue(i))))
+    call Printf(fmt='%r', r=(/rvalue(i)/))
   end do
   deallocate(rvalue, stat=stat)
   if (stat /= 0) stat = GT_ENOMEM
